academicons: Academicons icons

download_academiconsR Documentation

Academicons icons

Description

Academicons is a specialist icon font for academics. It contains icons for websites and organisations related to academia that are often missing from mainstream font packages. It can be used by itself, but its primary purpose is to be used as a supplementary package alongside a larger icon set.

Usage

download_academicons(version = "dev")

academicons(name)

Arguments

version

Version of the library

name

Name of the icon

Value

download_academicons() invisibly returns the academicons icon set after downloading and installing its SVG files locally.

academicons(name) returns an icons vector (an SVG tag) for the requested icon.

License

Academicons is distributed under the SIL Open Font License 1.1 (see the project README for details).


icons documentation built on Sept. 3, 2026, 5:10 p.m.