| download_fontawesome | R Documentation |
Font Awesome icons
download_fontawesome(version = "dev")
fontawesome(name, style = NULL)
version |
Version of the library |
name |
Name of the icon |
style |
Style of the icon. If NULL, a default style will be chosen for the specified icon. |
download_fontawesome() invisibly returns the fontawesome
icon set after downloading and installing its SVG files locally.
fontawesome(name, style) returns an icons vector (an SVG tag) for
the requested icon.
This package uses Font Awesome Free. Its icons are distributed under the CC BY 4.0 License, which requires attribution when the icons are used.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.