| download_google_material | R Documentation |
Google's Material design icons
download_google_material(version = "dev")
google_material(name, category = NULL, theme = NULL)
version |
Version of the library |
name |
Name of the icon |
category |
The icon's category, either "action", "alert", "av", "communication", "content", "device", "editor", "file", "hardware", "home", "image", "maps", "navigation", "notification", "places", "social", or "toggle" |
theme |
The style variant for the icon, requires v4.0.0 or greater. Available themes vary by icon, but can be either "filled", "outlined", "round", "sharp", or "twotone". If NULL, it will default to the first available variant in this order. |
download_google_material() invisibly returns the
google_material icon set after downloading and installing its SVG
files locally.
google_material(name, category, theme) returns an icons vector (an
SVG tag) for the requested icon.
Material Design Icons are distributed under the Apache License 2.0.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.