icons-package: icons: Easily Insert SVG Icons into R Outputs

icons-packageR Documentation

icons: Easily Insert SVG Icons into R Outputs

Description

logo

Provides tools to download, style, and insert scalable vector graphics (SVG) icons into R output, such as 'R Markdown' and 'Quarto' documents, 'Shiny' apps, 'gt' tables, and 'ggplot2' visualisations via the 'ggicons' package. Bundles popular icon libraries, such as 'Font Awesome' (https://fontawesome.com), 'Academicons' (https://jpswalsh.github.io/academicons/), and 'Material Design Icons' (https://fonts.google.com/icons), which are downloaded on demand to keep the package small, or build a custom icon set from any folder of local SVG files. Icon appearance, such as size, colour, and position, can be customised.

Author(s)

Maintainer: Mitchell O'Hara-Wild mail@mitchelloharawild.com (ORCID)

Authors:

Other contributors:

  • Earo Wang (ORCID) [contributor]

  • Timothy Hyndman (ORCID) [contributor]

  • Matthew Warkentin (ORCID) [contributor]

  • Tom Jemmett (ORCID) [contributor]

See Also

Useful links:


icons documentation built on Sept. 3, 2026, 5:10 p.m.