| download_simple_icons | R Documentation |
Simple Icons
download_simple_icons(version = "dev")
simple_icons(name)
version |
Version of the library |
name |
Name of the icon |
download_simple_icons() invisibly returns the simple_icons
icon set after downloading and installing its SVG files locally.
simple_icons(name) returns an icons vector (an SVG tag) for the
requested icon.
The Simple Icons artwork is distributed under the CC0 1.0 Universal License. Many of the icons depict third-party brands and logos which may be protected as trademarks; read Simple Icons' legal disclaimer before using them.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.