| download_academicons | R Documentation |
Academicons is a specialist icon font for academics. It contains icons for websites and organisations related to academia that are often missing from mainstream font packages. It can be used by itself, but its primary purpose is to be used as a supplementary package alongside a larger icon set.
download_academicons(version = "dev")
academicons(name)
version |
Version of the library |
name |
Name of the icon |
download_academicons() invisibly returns the academicons icon
set after downloading and installing its SVG files locally.
academicons(name) returns an icons vector (an SVG tag) for the
requested icon.
Academicons is distributed under the SIL Open Font License 1.1 (see the project README for details).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.