icon_installed: Check if an icon set is installed.

View source: R/icon.R

icon_installedR Documentation

Check if an icon set is installed.

Description

This function will return TRUE if the icons for an icon set are installed. If they aren't, they can be installed using the appropriate ⁠download_*()⁠ function.

Usage

icon_installed(x)

Arguments

x

An icon set (such as fontawesome).

Value

A single TRUE or FALSE.

Examples

icon_installed(fontawesome)


icons documentation built on Sept. 3, 2026, 5:10 p.m.