| icon_save | R Documentation |
Store icons in a local directory to simplify sharing of documents containing icons. Bundling icons with your document or app avoids the need for collaborators or servers to have all icons from a library installed.
icon_save(icons, path = ".")
icons |
A named list of icons, the names specify the icon's name in the new icon set. |
path |
A directory to save the icons into. |
Invisibly, the icon_set created from the newly saved SVG files
at path.
if(icon_installed(fontawesome) && icon_installed(ionicons)){
path <- tempfile()
dir.create(path)
icon_save(
list(arrow = fontawesome$solid$`arrow-right`, alarm = ionicons$alarm),
path = path
)
app_icons <- icon_set(path)
app_icons$arrow
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.