| icons-package | R Documentation |
Provides tools to download, style, and insert scalable vector graphics (SVG) icons into R output, such as 'R Markdown' and 'Quarto' documents, 'Shiny' apps, 'gt' tables, and 'ggplot2' visualisations via the 'ggicons' package. Bundles popular icon libraries, such as 'Font Awesome' (https://fontawesome.com), 'Academicons' (https://jpswalsh.github.io/academicons/), and 'Material Design Icons' (https://fonts.google.com/icons), which are downloaded on demand to keep the package small, or build a custom icon set from any folder of local SVG files. Icon appearance, such as size, colour, and position, can be customised.
Maintainer: Mitchell O'Hara-Wild mail@mitchelloharawild.com (ORCID)
Authors:
Mitchell O'Hara-Wild mail@mitchelloharawild.com (ORCID)
Other contributors:
Earo Wang (ORCID) [contributor]
Timothy Hyndman (ORCID) [contributor]
Matthew Warkentin (ORCID) [contributor]
Tom Jemmett (ORCID) [contributor]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.